[yum-cvs] yum-utils yumdownloader.py,1.22,1.23

Tim Lauridsen timlau at linux.duke.edu
Mon Jun 18 09:47:00 UTC 2007


Update of /home/groups/yum/cvs/yum-utils
In directory login1.linux.duke.edu:/tmp/cvs-serv21672

Modified Files:
	yumdownloader.py 
Log Message:
Make 'yumdownloader --source kernel' work as nonroot with yum 3.2 & and current CVS Head.

Index: yumdownloader.py
===================================================================
RCS file: /home/groups/yum/cvs/yum-utils/yumdownloader.py,v
retrieving revision 1.22
retrieving revision 1.23
diff -u -r1.22 -r1.23
--- yumdownloader.py	5 Jun 2007 17:50:28 -0000	1.22
+++ yumdownloader.py	18 Jun 2007 09:46:58 -0000	1.23
@@ -59,6 +59,8 @@
                 self.logger.error("Error: Could not make cachedir, exiting")
                 sys.exit(50)
             self.repos.setCacheDir(cachedir)
+            # Turn of cache
+            self.conf.cache = 0
 
         # Setup yum (Ts, RPM db, Repo & Sack)
         self.doUtilYumSetup()
@@ -76,8 +78,8 @@
             for r in self.repos.findRepos(srcrepo):
                 self.logger.info('Enabling %s repository' % r.id)
                 r.enable()
-                # Setup the repo
-                self._getRepos(thisrepo=r.id,doSetup=True)
+                # Setup the repo, without a cache
+                r.setup(0)
                 # Setup pkgSack with 'src' in the archlist
                 self._getSacks(archlist=archlist,thisrepo=r.id)
         




More information about the Yum-cvs-commits mailing list